/**
* @file Scripts to convert SEDRA 3 text database to JavaScript
* @version 1.2.9
* @author Greg Borota
* @copyright (c) 2017 Greg Borota.
*
* Based on SEDRA 3, copyright (c) 1996 GEORGE A. KIRAZ
*
* @license MIT
*
* The following license applies to all parts of this software except as
* documented below:
*
* Permission is hereby granted, free of charge, to any person obtaining a copy
* of this software and associated documentation files (the "Software"), to deal
* in the Software without restriction, including without limitation the rights
* to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
* copies of the Software, and to permit persons to whom the Software is
* furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
* AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM
* OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
* SOFTWARE.
*
* Files located in the node_modules and vendor directories are externally
* maintained libraries used by this software, which have their own licenses;
* their terms may differ from the terms above.
*
* Sedrajs contains a JavaScript representation of SEDRA 3 text database, with
* additional supporting JS data structures and utilities. SEDRA database portion
* is subject to the restrictions imposed by the authors of SEDRA 3 text database.
* The database was originally downloaded from <http://www.bethmardutho.org/>.
*
*       For additional information on the structure of the Database, see
*          G. Kiraz, `Automatic Concordance Generation of Syriac Texts',
*          in VI Symposium Syriacum 1992, ed. R. Lavenant, Orientalia
*          Christiana Analecta 247, Rome, 1994.
*
*       You are allowed to use SEDRA III for personal and academic
*       purposes provided that:
*       1. You do NOT redistribute any altered versions of the files.
*       2. You do NOT redistribute any files for any kind of profit.
*       3. You acknowledge in any publication whose results make use of
*          SEDRA III, by any means, using a formula similar to the
*          following:
*       "This work makes use of the Syriac Electronic Data
*        Retrieval Archive (SEDRA) by George A. Kiraz, distributed
*        by the Syriac Computing Institute."
*       You should also cite the paper mentioned above.
*
* See sedra/SEDRA3.DOC for additional details.*/
"use strict";Object.defineProperty(exports,"__esModule",{value:!0});var path=require("path"),fs=require("fs"),sedraParse=require("sedra-parse"),realpathAsync=function(e){return new Promise(function(r,t){fs.realpath(e,"utf8",function(e,o){e?t(e):r(o)})})},mkdirAsync=function(e){return new Promise(function(r,t){fs.mkdir(e,function(e){e&&"EEXIST"!==e.code?t(e):r()})})},readFileAsync=function(e){return new Promise(function(r,t){fs.readFile(e,"utf8",function(e,o){e?t(e):r(o)})})},writeFileAsync=function(e,r){return new Promise(function(t,o){fs.writeFile(e,r,"utf8",function(e){e?o(e):t()})})},outDir=__dirname+"/../",outSedraDir=outDir+"sedra/",throwError=function(e){throw e},readDb=function(e,r){return realpathAsync(path.join(__dirname,"../../sedra",e)).then(function(e){return readFileAsync(e).then(function(e){return r(e)}).catch(throwError)}).catch(throwError)},writeDb=function(e,r){return writeFileAsync(e,r).then(function(){realpathAsync(e).then(function(e){global.console.log("Saved '"+e+"'")}).catch(throwError)}).catch(throwError)},convertDb=function(){var e=null,r=null,t=null,o=null,s=null,n=null,a=readDb("ROOTS.TXT",sedraParse.getRoots).then(function(r){e=r}),i=readDb("LEXEMES.TXT",sedraParse.getLexemes).then(function(e){r=e}),d=readDb("WORDS.TXT",sedraParse.getWords).then(function(e){t=e}),u=readDb("ENGLISH.TXT",sedraParse.getEnglish).then(function(e){o=e}),l=readDb("ETIMOLGY.TXT",sedraParse.getEtymology).then(function(e){s=e}),m=readDb("BFBS.TXT",sedraParse.getUbs).then(function(e){n=e});return Promise.all([a,i,d,u,l,m,mkdirAsync(outSedraDir)]).then(function(){var a=""+("o="+e)+("m="+r)+("d="+t.words)+("n="+o.english)+("y="+s.etymology)+("u="+n.ubs),i=outSedraDir+"roots.js",d=outSedraDir+"lexemes.js",u=outSedraDir+"words.js",l=outSedraDir+"english.js",m=outSedraDir+"etymology.js",f=outSedraDir+"ubs.js",c=outSedraDir+"noW.js",D=outSedraDir+"noY.js",h=outSedraDir+"englishLid.js",y=outSedraDir+"etymologyLid.js",b=outSedraDir+"ubsReference.js",p=outDir+"sedrajs.esm.js",w=outDir+"sedrajs.js";return Promise.all([writeDb(i,"import{makeRoot as r}from'sedra-model';export default "+e),writeDb(d,"import{makeLexeme as l}from'sedra-model';export default "+r),writeDb(u,"import{makeWord as w}from'sedra-model';export default "+t.words),writeDb(l,"import{makeEnglish as e}from'sedra-model';export default "+o.english),writeDb(m,"import{makeEtymology as t}from'sedra-model';export default "+s.etymology),writeDb(f,"export default "+n.ubs),writeDb(c,"export default "+t.noW),writeDb(D,"export default "+t.noY),writeDb(h,"export default "+o.lids),writeDb(y,"export default "+s.lids),writeDb(b,"export default "+n.reference),writeDb(p,"import{makeRoot as r,makeLexeme as l,makeWord as w,makeEnglish as e,makeEtymology as t}from'sedra-model';var o,m,d,n,y,u;"+a+"export{o as roots,m as lexemes,d as words,n as english,y as etymology,u as ubs};"),writeDb(w,"!function(g,f){'object'==typeof exports&&'undefined'!=typeof module?f(exports,require('sedra-model')):'function'==typeof define&&define.amd?define(['exports','sedra-model'],f):f(g.sedrajs={},g.sedraModel)}(this,function(x,s){'use strict';var r=s.makeRoot,l=s.makeLexeme,w=s.makeWord,e=s.makeEnglish,t=s.makeEtymology,o,m,d,n,y,u;"+a+"x.roots=o,x.lexemes=m,x.words=d,x.english=n,x.etymology=y,x.ubs=u,Object.defineProperty(x,'__esModule',{value:!0})});")])}).catch(throwError)};exports.readDb=readDb,exports.writeDb=writeDb,exports.convertDb=convertDb,exports.mkDir=mkdirAsync;
